summaryrefslogtreecommitdiffstats
path: root/sys
diff options
context:
space:
mode:
authored <ed@FreeBSD.org>2009-02-14 19:46:28 +0000
committered <ed@FreeBSD.org>2009-02-14 19:46:28 +0000
commit900dd11db2994e229a8ab40f7431f0d125b97b86 (patch)
tree00d610f5c7cd924536b3b5ba1ef2da124b6bbf60 /sys
parent1ecfdf51e91bea1ea0c50525fec28021e62b70b4 (diff)
downloadFreeBSD-src-900dd11db2994e229a8ab40f7431f0d125b97b86.zip
FreeBSD-src-900dd11db2994e229a8ab40f7431f0d125b97b86.tar.gz
Remove unneeded execute-permissions from the USB2 device node.
Giving a charactere device execute permissions doesn't have any use. Right now there isn't a single device node in /dev that has it, except the USB2 device node, so remove it. Approved by: hps, thompsa
Diffstat (limited to 'sys')
-rw-r--r--sys/dev/usb2/core/usb2_dev.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sys/dev/usb2/core/usb2_dev.c b/sys/dev/usb2/core/usb2_dev.c
index ee83411..18b1f9f 100644
--- a/sys/dev/usb2/core/usb2_dev.c
+++ b/sys/dev/usb2/core/usb2_dev.c
@@ -1466,13 +1466,13 @@ usb2_dev_init_post(void *arg)
* should never be opened. Therefore a space character is
* appended after the USB device name.
*
* NOTE: The permissions of this device is 0777, because we
* check the permissions again in the open routine against the
* real USB permissions which are not 0777. Else USB access
* will be limited to one user and one group.
*/
usb2_dev = make_dev(&usb2_devsw, 0, UID_ROOT, GID_OPERATOR,
- 0777, USB_DEVICE_NAME " ");
+ 0666, USB_DEVICE_NAME " ");
if (usb2_dev == NULL) {
DPRINTFN(0, "Could not create usb bus device!\n");
}
@@ -1466,13 +1466,13 @@ usb2_dev_init_post(void *arg)
* appended after the USB device name.
*
- * NOTE: The permissions of this device is 0777, because we
+ * NOTE: The permissions of this device is 0666, because we
* check the permissions again in the open routine against the
@@ -1466,13 +1466,13 @@ usb2_dev_init_post(void *arg)
* check the permissions again in the open routine against the
- * real USB permissions which are not 0777. Else USB access
+ * real USB permissions which are not 0666. Else USB access
* will be limited to one user and one group.
*/
OpenPOWER on IntegriCloud